==> glib2-2.28.6-i586-2vl70.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2800.6 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2800.6 libgobject-2.0.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2800.6 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libgio-2.0.so.0 )
( cd usr/lib ; ln -sf libgio-2.0.so.0.2800.6 libgio-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2800.6 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2800.6 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libgthread-2.0.so )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2800.6 libgthread-2.0.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2800.6 libgmodule-2.0.so )
( cd usr/lib ; rm -rf libgio-2.0.so )
( cd usr/lib ; ln -sf libgio-2.0.so.0.2800.6 libgio-2.0.so )
( cd usr/lib ; rm -rf libglib-2.0.so )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2800.6 libglib-2.0.so )
( cd usr/doc/glib-2.28.6 ; rm -rf html )
( cd usr/doc/glib-2.28.6 ; ln -sf /usr/share/gtk-doc/html/gobject html )

# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="`dirname $NEW`/`basename $NEW .new`"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
      mv $NEW $OLD
    elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
      # toss the redundant copy
      rm $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

# Prepare the new configuration files
for file in etc/profile.d/libglib2.csh.new etc/profile.d/libglib2.sh.new ; do
  if test -e $(dirname $file)/$(basename $file .new) ; then
    if [ ! -x $(dirname $file)/$(basename $file .new) ]; then
      chmod 644 $file
     else
      chmod 755 $file
    fi
  fi
  config $file
done

# Try to run this.  If it fails, no biggie.
chroot . /usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas/ 1> /dev/null 2> /dev/null

==> glib2-2.28.7-i486-1vl70.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2800.7 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2800.7 libglib-2.0.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2800.7 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libgmodule-2.0.so )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2800.7 libgmodule-2.0.so )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2800.7 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libgthread-2.0.so )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2800.7 libgthread-2.0.so )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2800.7 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2800.7 libgobject-2.0.so )
( cd usr/lib ; rm -rf libgio-2.0.so.0 )
( cd usr/lib ; ln -sf libgio-2.0.so.0.2800.7 libgio-2.0.so.0 )
( cd usr/lib ; rm -rf libgio-2.0.so )
( cd usr/lib ; ln -sf libgio-2.0.so.0.2800.7 libgio-2.0.so )
( cd usr/doc/glib-2.28.7 ; rm -rf html )
( cd usr/doc/glib-2.28.7 ; ln -sf /usr/share/gtk-doc/html/gobject html )

# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="`dirname $NEW`/`basename $NEW .new`"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
      mv $NEW $OLD
    elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
      # toss the redundant copy
      rm $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

# Prepare the new configuration files
for file in etc/profile.d/libglib2.csh.new etc/profile.d/libglib2.sh.new ; do
  if test -e $(dirname $file)/$(basename $file .new) ; then
    if [ ! -x $(dirname $file)/$(basename $file .new) ]; then
      chmod 644 $file
     else
      chmod 755 $file
    fi
  fi
  config $file
done

# Try to run this.  If it fails, no biggie.
chroot . /usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas/ 1> /dev/null 2> /dev/null
